/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.event.bean;

import org.ow2.easybeans.api.event.bean.EZBEventBeanAfterCreation;
import org.ow2.easybeans.event.AbstractEvent;

/**
 * Event used before the creation of beans.
 * @author Florent Benoit
 * @param <T> the type of the class
 */
public class EventBeanAfterCreation<T> extends AbstractEvent implements EZBEventBeanAfterCreation<T> {

    /**
     * Bean class.
     */
    private Class<T> clazz;

    /**
     * Build a new Event for before the creation of an EJB3 instance.
     * @param source the event source
     * @param clazz the class of the bean
     */
    public EventBeanAfterCreation(final String source, final Class<T> clazz) {
        super(source);
        this.clazz = clazz;

    }

    /**
     * @return the bean class
     */
    public Class<T> getBeanClass() {
        return this.clazz;
    }

}
